@@ -7,8 +7,8 @@ ERROR_STATUS_FORMAT = 'Singularity responded with an invalid status code ({0})'
 def get_json_response(uri, params={}):
   singularity_response = requests.get(uri, params=params)
   if singularity_response.status_code < 199 or singularity_response.status_code > 299:
-    sys.stderr.write(uri + '\n')
-    sys.stderr.write(str(params) + '\n')
+    sys.stderr.write('{0} params:{1}\n'.format(uri, str(params)))
     sys.stderr.write(colored(ERROR_STATUS_FORMAT.format(singularity_response.status_code), 'red') + '\n')
+    return {}
   return singularity_response.json()
 
